MiCO CUBE is the name of the `MXCHIP-MiCO <http://mico.io>`_ command line tool, packaged as mico-cube, which enables the full MiCO workflow: repositories version control, maintaining dependencies, publishing code, updating from remotely hosted repositories, and invoking MXCHIP MiCO's own build system and export functions, among other operations.


Installation
============
MiCO CUBE is a Python script, so you'll need Python installed in order to use it. MiCO CUBE was tested with Python 2.7.

MiCO CUBE supports Git repositories, so you'll also need to install Git.

Get Started
===========
The best way to get started is to `read the documentation on <https://code.aliyun.com/mico/mico-cube/README.md>`_.

License
=======
MiCO CUBE is licensed under Apache-2.0
